@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 #
 # Univention Directory Listener
-"""listener script for setting ldap server."""
 #
 # Copyright 2004-2021 Univention GmbH
 #
@@ -30,21 +29,24 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+"""listener script for setting ldap server."""
+
 from __future__ import absolute_import
 
+from typing import Dict, List, Optional  # noqa F401
+
 import listener
 import univention.config_registry
-
 import univention.debug as ud
 
 name = 'ldap_server'
 description = 'Update upstream LDAP server list'
 filter = '(&(objectClass=univentionDomainController)(|(univentionServerRole=master)(univentionServerRole=backup)))'
-attributes = []
+attributes = []  # type: List[str]
 
 
 def handler(dn, new, old):
-	# type: (str, dict, dict) -> None
+	# type: (str, Dict[str, List[bytes]], Dict[str, List[bytes]]) -> None
 	"""Handle change in LDAP."""
 	ucr = univention.config_registry.ConfigRegistry()
 	ucr.load()
@@ -71,7 +73,7 @@ def handler(dn, new, old):
 
 
 def add_ldap_server(ucr, name, domain, role):
-	# type: (dict, str, str, str) -> None
+	# type: (Dict[str, str], str, str, str) -> None
 	"""Add LDAP server."""
 	ud.debug(ud.LISTENER, ud.INFO, 'LDAP_SERVER: Add ldap_server %s' % name)
 
@@ -98,7 +100,7 @@ def add_ldap_server(ucr, name, domain, role):
 
 
 def remove_ldap_server(ucr, name, domain, role):
-	# type: (dict, str, str, str) -> None
+	# type: (Dict[str, str], str, str, str) -> None
 	"""Remove LDAP server."""
 	ud.debug(ud.LISTENER, ud.INFO, 'LDAP_SERVER: Remove ldap_server %s' % name)
 
